==> situare_1.0-0.tar.gz: situare-1.0/src/engine/mceprivate.cpp <==
/*
   Situare - A location system for Facebook
   Copyright (C) 2010  Ixonos Plc. Authors:

       Jussi Laitinen - jussi.laitinen@ixonos.com

   Situare is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   version 2 as published by the Free Software Foundation.

   Situare is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Situare; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
   USA.
*/

#include <QString>
#include <QDebug>
#include <QTimer>

#include <mce/dbus-names.h>
#include <mce/mode-names.h>

#include "mce.h"
#include "mceprivate.h"

const int DISPLAY_STATE_INDEX = 0;

static QDBusConnection dBusConnection = QDBusConnection::systemBus();

MCEPrivate::MCEPrivate(QObject *parent)
    : QObject(parent),
      m_displayOn(true)
{
    qDebug() << __PRETTY_FUNCTION__;

    m_parent = static_cast<MCE*>(parent);

    m_dBusInterface = new QDBusInterface(MCE_SERVICE, MCE_REQUEST_PATH,
                                       MCE_REQUEST_IF, dBusConnection, this);

    dBusConnection.connect(MCE_SERVICE, MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
                           MCE_DISPLAY_SIG, this, SLOT(displayStateChanged(const QDBusMessage &)));

    m_dBusInterface->callWithCallback(MCE_DISPLAY_STATUS_GET, QList<QVariant>(), this,
                                      SLOT(setDisplayState(QString)),
                                      SLOT(displayStateError(QDBusError)));
}

void MCEPrivate::displayStateChanged(const QDBusMessage &message)
{
    qDebug() << __PRETTY_FUNCTION__;

    QString state = message.arguments().at(DISPLAY_STATE_INDEX).toString();
    setDisplayState(state);
}

void MCEPrivate::displayStateError(const QDBusError &error)
{
    qDebug() << __PRETTY_FUNCTION__;

    Q_UNUSED(error);
}

bool MCEPrivate::isDisplayOn()
{
    qDebug() << __PRETTY_FUNCTION__;

    return m_displayOn;
}

void MCEPrivate::setDisplayState(const QString &state)
{
    qDebug() << __PRETTY_FUNCTION__;

    if (!state.isEmpty()) {
        if (state == MCE_DISPLAY_ON_STRING) {
            m_displayOn = true;
            emit m_parent->displayStateChanged(true);
        }
        else if (state == MCE_DISPLAY_OFF_STRING) {
            m_displayOn = false;
            emit m_parent->displayStateChanged(false);
        }
    }
}

==> situare_2.0b-1.tar.gz: situare-2.0b/src/engine/mceprivate.cpp <==
/*
   Situare - A location system for Facebook
   Copyright (C) 2010  Ixonos Plc. Authors:

       Jussi Laitinen - jussi.laitinen@ixonos.com

   Situare is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   version 2 as published by the Free Software Foundation.

   Situare is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Situare; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
   USA.
*/

#include <QString>
#include <QDebug>
#include <QTimer>
#include <QFile>
#include <QtXml/QDomDocument>

#include <mce/dbus-names.h>
#include <mce/mode-names.h>

#include "mce.h"
#include "mceprivate.h"

const int DISPLAY_STATE_INDEX = 0;

static QDBusConnection dBusConnection = QDBusConnection::systemBus();

MCEPrivate::MCEPrivate(QObject *parent)
    : QObject(parent),
      m_displayOn(true)
{
    qDebug() << __PRETTY_FUNCTION__;

    m_parent = static_cast<MCE*>(parent);

    m_dBusInterface = new QDBusInterface(MCE_SERVICE, MCE_REQUEST_PATH,
                                       MCE_REQUEST_IF, dBusConnection, this);

    dBusConnection.connect(MCE_SERVICE, MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
                           MCE_DISPLAY_SIG, this, SLOT(displayStateChanged(const QDBusMessage &)));

    m_dBusInterface->callWithCallback(MCE_DISPLAY_STATUS_GET, QList<QVariant>(), this,
                                      SLOT(setDisplayState(QString)),
                                      SLOT(displayStateError(QDBusError)));
}

void MCEPrivate::displayStateChanged(const QDBusMessage &message)
{
    qDebug() << __PRETTY_FUNCTION__;

    QString state = message.arguments().at(DISPLAY_STATE_INDEX).toString();
    setDisplayState(state);
}

void MCEPrivate::displayStateError(const QDBusError &error)
{
    qDebug() << __PRETTY_FUNCTION__;

    Q_UNUSED(error);
}

bool MCEPrivate::isDisplayOn()
{
    qDebug() << __PRETTY_FUNCTION__;

    return m_displayOn;
}

void MCEPrivate::setDisplayState(const QString &state)
{
    qDebug() << __PRETTY_FUNCTION__;

    if (!state.isEmpty()) {
        if (state == MCE_DISPLAY_ON_STRING) {
            m_displayOn = true;
            emit m_parent->displayOff(false);
        }
        else if (state == MCE_DISPLAY_OFF_STRING) {
            m_displayOn = false;
            emit m_parent->displayOff(true);
        }
    }
}

bool MCEPrivate::isTouchscreenVibrationEnabled()
{
    QDomDocument doc;
    QFile file("/var/lib/gconf/system/osso/dsm/vibra/\%gconf.xml");

    if (!file.open(QIODevice::ReadOnly))
        return false;
    if (!doc.setContent(&file)) {
        file.close();
        return false;
    }

    file.close();

    QDomNodeList domNodeList = doc.elementsByTagName("entry");

    for (int i = 0; i < domNodeList.count(); ++i) {

        QDomElement element = domNodeList.at(i).toElement();

        if ((!element.isNull()) && (element.hasAttribute("name")) &&
            (element.attribute("name") == "touchscreen_vibra_enabled")) {

            return QVariant(element.attribute("value", "false")).toBool();
        }
    }

    return false;
}

void MCEPrivate::stopVibration()
{
    qDebug() << __PRETTY_FUNCTION__;

    m_dBusInterface->call(MCE_ACTIVATE_VIBRATOR_PATTERN, "PatternPowerKeyPress");
}

void MCEPrivate::vibrationFeedback()
{
    qDebug() << __PRETTY_FUNCTION__;

    if (isTouchscreenVibrationEnabled()) {
        m_dBusInterface->call(MCE_ACTIVATE_VIBRATOR_PATTERN, "PatternPowerKeyPress");

        const int VIBRATION_TIME = 40;  //Vibration time in milliseconds
        QTimer::singleShot(VIBRATION_TIME, this, SLOT(stopVibration()));
    }
}
